@@ -11,7 +11,7 @@
 calcPolyInL <- function(raw, age, model) {
   k <- model$k
   coeff <- model$coefficients
-  return(calcPolyInLBase(raw, age, coeff, k))
+  return(calcPolyInLBase2(raw, age, coeff, k))
 }
 
 #' Internal function for retrieving regression function coefficients at specific age
@@ -89,6 +89,47 @@ calcPolyInLBase <- function(raw, age, coeff, k) {
   return(coefficientPolynom)
 }
 
+#' Internal function for retrieving regression function coefficients at specific
+#' age (optimized)
+#'
+#' The function is an inline for searching zeros in the inverse regression
+#' function. It collapses the regression function at a specific age and
+#' simplifies the coefficients. Optimized version of the prior 'calcPolyInLBase'
+#' @param raw The raw value (subtracted from the intercept)
+#' @param age The age
+#' @param coeff The cNORM regression model coefficients
+#' @param k The cNORM regression model power parameter
+#'
+#' @return The coefficients
+calcPolyInLBase2 <- function(raw, age, coeff, k) {
+  nam <- names(coeff)
+  coeff <- as.numeric(coeff)
+
+  # use regex to identify powers of A
+  positionsA <- regexpr("A\\d", nam)
+  positionsA[positionsA == -1] <- 0
+  powerA <- as.numeric(gsub("A", "", regmatches(nam, positionsA)))
+  powerA[is.na(powerA)] <- 0
+
+  # modify coefficients by powers of A
+  coeff <- coeff * (age^powerA)
+
+  # use regex to identify powers of L
+  positionsL <- rep("", length(nam))
+  indices <- grep("^L", nam)
+  positionsL[indices] <- substr(nam[indices], start=2, stop=2)
+  positionsL[positionsL==""] <- "0"
+  positionsL <- as.numeric(positionsL)
+  coefficients <- rep(0, k + 1)
+
+  # iterate through coefficients
+  for(j in 0:k)
+    coefficients[j + 1] <- sum(coeff[positionsL==j])
+
+  coefficients[1] <-  coefficients[1] - raw
+  return(coefficients)
+}
+
 predictNormByRoots <- function(raw, age, model, minNorm, maxNorm, polynom = NULL, force = FALSE, covariate = NULL) {
 
   if(!is.null(covariate)){
@@ -99,7 +140,7 @@ predictNormByRoots <- function(raw, age, model, minNorm, maxNorm, polynom = NULL
   }
 
   if (is.null(polynom)) {
-    polynomForPrediction <- calcPolyInLBase(
+    polynomForPrediction <- calcPolyInLBase2(
       raw = raw,
       age = age,
       coeff = model$coefficients,
@@ -116,13 +157,14 @@ predictNormByRoots <- function(raw, age, model, minNorm, maxNorm, polynom = NULL
   # only one real part as a solution within correct range
   if (length(output) == 1 && output >= minNorm && output <= maxNorm) {
     return(output)
-  } else {
-    # not exactly one plausible solution, search for alternative on correct side of distribution
+  }
+
+  # not exactly one plausible solution, search for alternative on correct side of distribution
     median <- predictRaw(model$scaleM, age, model$coefficients, minRaw = model$minRaw, maxRaw = model$maxRaw)
     if (raw > median) {
-      output <- output[output > model$scaleM && output <= maxNorm]
+      output <- output[output > model$scaleM & output <= maxNorm]
     } else if (raw < median) {
-      output <- output[output < model$scaleM && output >= minNorm]
+      output <- output[output < model$scaleM & output >= minNorm]
     } else {
       return(model$scaleM)
     }
@@ -160,7 +202,7 @@ predictNormByRoots <- function(raw, age, model, minNorm, maxNorm, polynom = NULL
         return(maxNorm)
       }
     }
-  }
+
 }
 
 simplifyCoefficients <- function(coefficients = coefficients, covariate = covariate){
